@@ -48,13 +48,15 @@ cnc_error_cb (GdaClient *client, GdaConnection *cnc, GList *error_list, gpointer
 	g_return_if_fail (GDA_IS_CONNECTION (cnc));
 	g_return_if_fail (error_list != NULL);
 
-	error_dialog = gnome_db_error_dialog_new (_("Error viewer"));
-	gnome_db_error_dialog_show_errors (GNOME_DB_ERROR_DIALOG (error_dialog),
-					   error_list);
+	if (error_list != NULL) {
+		error_dialog = gnome_db_error_dialog_new (_("Error viewer"));
+		gnome_db_error_dialog_show_errors (GNOME_DB_ERROR_DIALOG (error_dialog),
+						   error_list);
 
-	/* FIXME: add to an internal list, to be able to get all the errors occured
-	   for this connection at a later time */
-	gda_error_list_free (error_list);
+		/* FIXME: add to an internal list, to be able to get all the errors occured
+		   for this connection at a later time */
+		gda_error_list_free (error_list);
+	}
 }
 
 /*
@@ -140,3 +142,9 @@ components_connection_close (GdaConnection *cnc)
 	g_return_if_fail (GDA_IS_CONNECTION (cnc));
 	gda_connection_close (cnc);
 }
+
+void
+components_connection_close_all (void)
+{
+	gda_client_close_all_connections (client);
+}
