@@ -23,6 +23,7 @@
 #include <config.h>
 #include <bonobo/bonobo-i18n.h>
 #include <libgda/gda-config.h>
+#include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gtk/gtkbbox.h>
 #include <gtk/gtkbutton.h>
 #include <gtk/gtkdialog.h>
@@ -240,20 +241,27 @@ setup_window (GnomeDbShell *shell)
 static void
 config_changed_cb (const gchar *path, gpointer user_data)
 {
+	BonoboUIComponent *uic;
 	GnomeDbShell *shell = (GnomeDbShell *) user_data;
 
 	g_return_if_fail (path != NULL);
 	g_return_if_fail (GNOME_DB_IS_SHELL (shell));
 
+	uic = gnome_db_window_get_ui_component (shell->priv->window);
+
 	if (!strcmp (path, GNOME_DB_SHELL_CONFIG_SHOW_SHORTCUT)) {
 		/* hide/show shortcut bar */
 		if (gda_config_get_boolean (GNOME_DB_SHELL_CONFIG_SHOW_SHORTCUT)) {
 			gtk_widget_show (shell->priv->shortcut);
 			shell->priv->show_shortcut = TRUE;
+			bonobo_ui_component_set_prop (uic, "/commands/ViewShortcutBar",
+						      "state", "1", NULL);
 		}
 		else {
 			gtk_widget_hide (shell->priv->shortcut);
 			shell->priv->show_shortcut = FALSE;
+			bonobo_ui_component_set_prop (uic, "/commands/ViewShortcutBar",
+						      "state", "0", NULL);
 		}
 	}
 	else if (!strcmp (path, GNOME_DB_SHELL_CONFIG_SHOW_SUMMARY)) {
@@ -261,10 +269,14 @@ config_changed_cb (const gchar *path, gpointer user_data)
 		if (gda_config_get_boolean (GNOME_DB_SHELL_CONFIG_SHOW_SUMMARY)) {
 			gtk_widget_show (shell->priv->summary);
 			shell->priv->show_summary = TRUE;
+			bonobo_ui_component_set_prop (uic, "/commands/ViewSummary",
+						      "state", "1", NULL);
 		}
 		else {
 			gtk_widget_hide (shell->priv->summary);
 			shell->priv->show_summary = FALSE;
+			bonobo_ui_component_set_prop (uic, "/commands/ViewSummary",
+						      "state", "0", NULL);
 		}
 	}
 }
@@ -357,22 +369,28 @@ verb_HelpAbout (BonoboUIComponent *uic, void *user_data, const char *path)
 		 * of 'Muller' */
 		N_("Reinhard Muller <reinhard@gnue.org>"),
 		"Gerhard Dieringer <gdieringer@compuserve.com>",
+		"Gonzalo Paniagua Javier <gonzalo@gnome-db.org>",
                 NULL
         };
         GtkWidget *dialog;
+	GdkPixbuf *logo;
 	GnomeDbShell *shell = (GnomeDbShell *) user_data;
 
 	g_return_if_fail (GNOME_DB_IS_SHELL (shell));
 
+	logo = gdk_pixbuf_new_from_file (GNOME_DB_PIXMAPDIR "/gnome-db.png", NULL);
+
         dialog = gnome_about_new (_("GNOME-DB"), VERSION,
                                   _("Copyright 2001, The GNOME Foundation"),
                                   _("GNOME Database front-end"),
-                                  authors, NULL, NULL, NULL);
+                                  authors, NULL, NULL, logo);
 	gtk_window_set_transient_for (GTK_WINDOW (dialog), shell->priv->window);
 	g_signal_connect (G_OBJECT (dialog), "destroy",
 			  G_CALLBACK (gtk_widget_destroyed), &dialog);
 
 	gtk_widget_show (dialog);
+
+	gdk_pixbuf_unref (logo);
 }
 
 static void
@@ -406,8 +424,9 @@ verb_ToolsSettings (BonoboUIComponent *uic, void *user_data, const char *path)
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), settings, TRUE, TRUE, 0);
 
 	/* show the dialog */
-	gtk_dialog_run (GTK_DIALOG (dialog));
-	gtk_widget_destroy (dialog);
+	g_signal_connect (G_OBJECT (dialog), "response",
+			  G_CALLBACK (gtk_widget_destroy), dialog);
+	gtk_widget_show (dialog);
 }
 
 static void
